package com.example.animoi;

import androidx.appcompat.app.AppCompatActivity;
import androidx.constraintlayout.widget.ConstraintLayout;
import androidx.core.app.ActivityOptionsCompat;
import androidx.viewpager.widget.ViewPager;

import android.app.Activity;
import android.content.Intent;
import android.content.SharedPreferences;
import android.os.Bundle;
import android.preference.PreferenceManager;
import android.text.Html;
import android.view.View;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.TextView;

import java.util.Timer;
import java.util.TimerTask;

public class MainActivity extends AppCompatActivity {

    private ConstraintLayout background;

    private ViewPager sSlideViewPager;
    private LinearLayout puntosLayout;

    private TextView[] puntos;

    private ImageView logo;

    private SliderAdapter sliderAdapter;

    private int currentPage;

    private int popUp, pantalla=0;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        //Obtenció de la variable popUp, per tal de saber si el menú emergent ja ha aparegut o no
        SharedPreferences prefs = PreferenceManager.getDefaultSharedPreferences(MainActivity.this);
        popUp = prefs.getInt("popUp", 0);
        popUpUsuario();

        //Assignació de variables associades a elements xml
        background = findViewById(R.id.bgMain);
        sSlideViewPager = findViewById(R.id.scrollMainActivity);
        puntosLayout = findViewById(R.id.puntosScroll);
        logo = findViewById(R.id.animoiLogo);

        //No mostrar logo quan aparega la pantalla emergent
        if(popUp == 0) logo.setAlpha(0f);

        //Adapter, permet que es cree el slider
        sliderAdapter = new SliderAdapter(this);
        sSlideViewPager.setAdapter(sliderAdapter);

        //Crea els punts
        puntosSlide(0);

        //Inicialitza el mètodue que permet saber a quina pàgina ens trobem
        sSlideViewPager.addOnPageChangeListener(viewListener);

    }

    //Mètode que fa aparèixer el menú emergent
    //Si la pantalla no ha eixit abans perquè l'usuari no ha entrat, la variable popUp serà 0 i per tant es mostrarà el menú
    //Si és 1, vol dir que l'usuari ja ha plenat les dades i no eixirà
    private void popUpUsuario() {
        if(popUp == 0) {
            try {
                Timer timer = new Timer();
                timer.schedule(new TimerTask() {

                    @Override
                    public void run() {
                        Intent intent = new Intent(getApplicationContext(), PopUpUsuario.class);
                        startActivity(intent);
                        overridePendingTransition(R.anim.fade_in, R.anim.fade_out);
                    }
                }, 1000);
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
    }

    //Mètode que permet accedir a una pàgina o altra segons on es clique
    //Es detecta a quina pàgina es troba l'usuari i la pàgina de destí canvia segons aquesta informació
    public void slectorSeccion(View view){
        if(currentPage==0){
            Intent iVolar = new Intent(MainActivity.this, Controles.class);
            iVolar.putExtra("pantalla", pantalla);
            MainActivity.this.startActivity(iVolar);
        }
        else if (currentPage==1){
            Intent iMontar = new Intent(MainActivity.this, Montar.class);
            MainActivity.this.startActivity(iMontar);

        }
        else if (currentPage==2){
            Intent iApren = new Intent(MainActivity.this, Apren.class);
            MainActivity.this.startActivity(iApren);
        }
    }


    //Crea els punts que indiquen a quina pàgina està l'usuari
    public void puntosSlide(int position){
        puntos = new TextView[3];
        puntosLayout.removeAllViews();

        for(int i=0; i<puntos.length; i++){

            puntos[i] = new TextView(this);
            puntos[i].setText(Html.fromHtml("&#8226;"));
            puntos[i].setTextSize(30);
            puntos[i].setTextColor(getResources().getColor(R.color.colorAccentTransparent));

            puntosLayout.addView(puntos[i]);
        }

        //Canvia el color del punt corresponent a la pàgina on es troba l'usuari
        if(puntos.length > 0){
            puntos[position].setTextColor(getResources().getColor(R.color.colorPaleta1));
        }
    }

    //Permet detectar a quina pàgina està l'usuari
    ViewPager.OnPageChangeListener viewListener = new ViewPager.OnPageChangeListener() {
        @Override
        public void onPageScrolled(int position, float positionOffset, int positionOffsetPixels) {

        }

        //Mètode que canvia el color de fons segons la pàgina a la que es trobe l'usuari
        @Override
        public void onPageSelected(int position) {
            puntosSlide(position);
            currentPage = position;
            if(position==0){
                background.setBackgroundResource(R.color.colorPaleta4);

            }else if (position==puntos.length - 1){
                background.setBackgroundResource(R.color.colorPaleta3);

            }else {
                background.setBackgroundResource(R.color.colorPaleta2);
            }
        }

        @Override
        public void onPageScrollStateChanged(int state) {

        }
    };

    //Mètodes onClick que permet accedir a la pàgina d'Uusari en clicar sobre la icona
    public void pagUsuario (View v){
        Intent intentUsuario = new Intent(MainActivity.this, Usuario.class);
        MainActivity.this.startActivity(intentUsuario);
    }

    //Mètodes onClick que permet accedir a la pàgina d'informació en clicar sobre la icona
    public void pagInfo (View v){
        Intent intentInfo = new Intent(MainActivity.this, Info.class);
        MainActivity.this.startActivity(intentInfo);
        overridePendingTransition(R.anim.fade_in, R.anim.fade_out);
    }
}

//https://www.youtube.com/watch?v=byLKoPgB7yA
//https://medium.com/acmvit/getting-started-with-lottie-animations-android-2c225ad2c467