package com.example.animoi;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.appcompat.app.AppCompatActivity;

import android.Manifest;
import android.content.ContentValues;
import android.content.Intent;
import android.content.SharedPreferences;
import android.content.pm.PackageManager;
import android.net.Uri;
import android.os.Build;
import android.os.Bundle;
import android.preference.PreferenceManager;
import android.provider.MediaStore;
import android.util.DisplayMetrics;
import android.view.Gravity;
import android.view.View;
import android.view.WindowManager;
import android.widget.EditText;
import android.widget.ImageView;
import android.widget.TextView;
import android.widget.Toast;

public class PopUpPublicar extends AppCompatActivity {

    private ImageView iconoUser, projectPhoto;
    private TextView name;
    private EditText titulo, descripcion;
    private int icono;
    private String nombre, tituloP, descripcionP;

    private static final int PERMISSION_CODE = 1000;
    private static final int IMAGE_CAPTURE_CODE = 1001;
    private Uri image_uri;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_pop_up_publicar);

        //Variables associades a elements xml
        iconoUser = findViewById(R.id.iconUserPublicar);
        name = findViewById(R.id.nameUserPublicar);
        projectPhoto = findViewById(R.id.selectPhoto);
        titulo = findViewById(R.id.etPubli);
        descripcion = findViewById(R.id.etDescPubli);

        //Pop up window
        //Obtenció del tamany de pantalla
        DisplayMetrics dm = new DisplayMetrics();
        getWindowManager().getDefaultDisplay().getMetrics(dm);

        //Associació de variables als valors anteriors
        int width = dm.widthPixels;
        int height = dm.heightPixels;


        //Creació del menú popUp segons les proporcions de la pantalla
        getWindow().setLayout((int)(width*.95), (int)(height*.85));
        if(width>2000){
            getWindow().setLayout((int)(width*.9), (int)(height*.85));
        }

        //Col·locació del menú popUp
        WindowManager.LayoutParams params = getWindow().getAttributes();
        params.gravity = Gravity.CENTER;
        params.x = -60;
        params.y = 25;
        getWindow().setAttributes(params);

        //Col·locació del menú popUp a la tableta
        if(width>2000){
            params.x = 0;
            params.y = -40;
            getWindow().setAttributes(params);
        }


        //Obté el nom i el número associat a la icona de l'usuari
        SharedPreferences prefs = PreferenceManager.getDefaultSharedPreferences(PopUpPublicar.this);
        icono = prefs.getInt("icono", 0);
        nombre = prefs.getString("user", "DEFAULT");
        name.setText(nombre);

        //Segons el id obtés, es mostra una icona o altra
        switch (icono){
            case 1:
                iconoUser.setImageResource(R.drawable.icono1);
                break;
            case 2:
                iconoUser.setImageResource(R.drawable.icono2);
                break;
            case 3:
                iconoUser.setImageResource(R.drawable.icono3);
                break;
            case 4:
                iconoUser.setImageResource(R.drawable.icono4);
                break;
            case 5:
                iconoUser.setImageResource(R.drawable.icono5);
                break;
            case 6:
                iconoUser.setImageResource(R.drawable.icono6);
                break;
        }

        //Mètode que demana permisos per fer una fotografía o controla si ja s'han concedit
        projectPhoto.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                //Request permission
                if (Build.VERSION.SDK_INT >=Build.VERSION_CODES.M){
                    if(checkSelfPermission(Manifest.permission.CAMERA) ==
                            PackageManager.PERMISSION_DENIED ||
                            checkSelfPermission(Manifest.permission.WRITE_EXTERNAL_STORAGE) ==
                                    PackageManager.PERMISSION_DENIED){
                        //Permiso no concedit, per tant ha de demanar-se
                        String[] permission = {Manifest.permission.CAMERA, Manifest.permission.WRITE_EXTERNAL_STORAGE};
                        //Mostrar popu permís
                        requestPermissions(permission, PERMISSION_CODE);
                    }
                    else{
                        //Ja hi ha permís, per tant, executar mètode
                        openCamera();
                    }
                }
                else{
                    //system os < marshallow
                }
            }
        });
    }

    //Mètode que obre la càmera i permet fer una fotografia
    public void openCamera(){
        ContentValues values = new ContentValues();
        values.put(MediaStore.Images.Media.TITLE, "Título nuevo");
        values.put(MediaStore.Images.Media.DESCRIPTION, "From Animoi");
        image_uri = getContentResolver().insert(MediaStore.Images.Media.EXTERNAL_CONTENT_URI, values);

        //Camera intent
        Intent cameraIntent = new Intent(MediaStore.ACTION_IMAGE_CAPTURE);
        cameraIntent.putExtra(MediaStore.EXTRA_OUTPUT, image_uri);
        startActivityForResult(cameraIntent, IMAGE_CAPTURE_CODE);
    }


    //Mètode que controla el resultat dels permisos
    @Override
    public void onRequestPermissionsResult(int requestCode, @NonNull String[] permissions, @NonNull int[] grantResults) {
        //Mètode que s'activa qual l'usuari accepta o denega els permisos
        switch (requestCode){
            case PERMISSION_CODE:{
                if (grantResults.length >0 && grantResults[0] ==
                    PackageManager.PERMISSION_GRANTED){
                    openCamera();
                }
                else{
                    //Permiso denegado
                    Toast.makeText(this, "Permiso denegado", Toast.LENGTH_SHORT).show();
                }
            }
        }
    }

    //Mètode que s'executa quan s'ha fet la fotografia
    @Override
    protected void onActivityResult(int requestCode, int resultCode, @Nullable Intent data) {
        if (resultCode == RESULT_OK){
            projectPhoto.setImageURI(image_uri);
        }
    }

    //Mètode que permetria publicar els projectes quan la pàgina web d'Animoi sigués funcional
    public void publicarProyecto(View view){
        //Recull els texts escrits per l'usuari i els guarda a variables
        tituloP = titulo.getText().toString();
        descripcionP = descripcion.getText().toString();

        Intent intentPublicarFin = new Intent(PopUpPublicar.this, MainActivity.class);
        startActivity(intentPublicarFin);
    }
}
